define(['exports', './lib/nfpromiser'], function (exports, _nfpromiser) {
  'use strict';

  /**
   * A proxy module that aggregates submodules
   * @module nf-promiser
   * @author Markus Neuy
   * @since 01.09.2016
   */

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  var _nfpromiser2 = _interopRequireDefault(_nfpromiser);

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }

  exports.default = _nfpromiser2.default;
});
define(['exports'], function (exports) {
  'use strict';

  /**
   * A module to utilize the nfPromiser function.
   * @module nf-promiser
   * @author Markus Neuy
   * @since 01.09.2016
   */

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = nfPromiser;


  /**
   * A helper function that converts node-style functions to use promises.
   * The last parameter of node-style functions is a callback-function that takes
   * err and result.
   * @param {Function} nf A node-style function like fs.readFile
   * @param {...*} arguments The arguments that should be passed to the function
   * @returns {Promise.<*>} A promise that resolves to the callback value or is rejected otherwise.
   */
  function nfPromiser(nf) {
    for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }

    if (typeof nf !== 'function') {
      throw new TypeError('First parameter has to be function');
    }
    return new Promise(function (res, rej) {
      return nf.apply(undefined, args.concat([function (e, r) {
        return e ? rej(e) : res(r);
      }]));
    });
  }
});
