'use strict';

/**
 * A module to utilize the nfPromiser function.
 * @module nf-promiser
 * @author Markus Neuy
 * @since 01.09.2016
 */
export default nfPromiser;

/**
 * A helper function that converts node-style functions to use promises.
 * The last parameter of node-style functions is a callback-function that takes
 * err and result.
 * @param {Function} nf A node-style function like fs.readFile
 * @param {...*} arguments The arguments that should be passed to the function
 * @returns {Promise.<*>} A promise that resolves to the callback value or is rejected otherwise.
 */
function nfPromiser (nf, ...args) {
    if (typeof nf !== 'function') {
        throw new TypeError('First parameter has to be function');
    }
    return new Promise((res, rej) => nf(...args, (e, r) => e ? rej(e) : res(r)));
}